pub struct HttpReplicationServer { /* private fields */ }Expand description
HTTP replication server wrapping an Arc<Mutex<Engine>>.
Call start(bind_addr) to spawn the server loop in a background thread.
Implementations
Sourceimpl HttpReplicationServer
impl HttpReplicationServer
Sourcepub fn new(engine: Arc<Mutex<Engine>>) -> Self
pub fn new(engine: Arc<Mutex<Engine>>) -> Self
Create a new server wrapping the provided engine.
Sourcepub fn start(
&self,
bind_addr: &str,
) -> Result<(JoinHandle<()>, u16), EdgestoreError>
pub fn start( &self, bind_addr: &str, ) -> Result<(JoinHandle<()>, u16), EdgestoreError>
Bind to bind_addr and start the request loop in a background thread.
Returns (JoinHandle, bound_port). The bound port is useful when bind_addr
uses port 0 (OS-assigned ephemeral port). The server runs until the process exits.